validation

package
v0.26.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IsRecursive

func IsRecursive(ctx context.Context) bool

func WithRecursive

func WithRecursive(ctx context.Context) context.Context

Types

type Defaulter added in v0.26.0

type Defaulter interface {
	Default(context.Context) error
}

Alternative interface similar to admission.Defaulter, but requires the object being defaulted is the receiver rather than being passed as an argument.

type Validator

type Validator interface {
	Validate(ctx context.Context) error
}

Jump to